{ config, ... }:

{
  imports = [ (import ./hardware-configuration.nix) ];

  services.xserver = {
    videoDrivers = [ "nvidia" ];
    # nvidiaXineramaInfoOrder sets primary display
    # DFP-0 is default and would set left monitor, DVI-D-0, to be primary
    screenSection = ''
      Option "metamodes" "DVI-D-0: 1920x1080 +0+0 {rotation=left}, HDMI-0: 1920x1080 +1080+420"
      Option "nvidiaXineramaInfoOrder" "DFP-1"
    '';
  };
  # https://www.sven.de/dpi/
  services.xserver.dpi = 92;

  services.blueman.enable = true;

  services.tailscale.enable = true;
  networking.firewall = {
    checkReversePath = "loose";
    trustedInterfaces = [ "tailscale0" ];
    allowedUDPPorts = [ config.services.tailscale.port ];
  };

  boot.loader = {
    efi = {
      canTouchEfiVariables = true;
      efiSysMountPoint = "/boot";
    };
    grub = {
      efiSupport = true;
      device = "nodev";
      useOSProber = true;
    };
  };

  # Support mounting NTFS partition
  boot.supportedFilesystems = [ "ntfs" ];
}
